@@ -266,6 +266,17 @@ class Directory(Pathtime):
     def file_extension(self):
         return ''
 
+    @property
+    def ctag(self):
+        return self.etag
+
+    @property
+    def color(self):
+        return None
+
+    def get_description(self):
+        return self.urlpath
+
     @property
     def text(self):
         return self.path
